# ti lox suck kok #

## ты лох ##

говнищеееееееееееее

---
# пуканье

пуканье

    from morwlox123 import fart

    fart.fart(100)

мегапуканье

    from morwlox123 import fart

    fart.mega_farting(100)

---

# песие пенин
песня_про_какашку_и_говняшку

    from morwlox123 import pesnya

    петь.песня_про_какашку_и_говняшку()

klazermp3

    from morwlox123 import pesnya

    петь.klazermp3()

рустам

    from morwlox123 import pesnya

    петь.рустам()

---

idi nax lol lox morw daun